#! /usr/bin/env python
# -*- coding: utf-8 -*-

from clint import args
from clint.textui import progress
import multiprocessing

"""
    args.all yields all the command line arguments in list.
    Also expands ~ 
    args.grouped yield --d or -d with passed params
"""

def main():
    print "welcome to test"



# -*- coding: utf-8

"""
crunch
``````
main interface for crunch

"""

from __future__ import absolute_import


#Meta data

__title__ = 'crunch'
__version__ = '0.0.2.1'
__build__ = 0x00002
__author__ = 'kracekumar'
__license__ = 'ISC'
__copyright__ = 'Copyright 2012 kracekumar'
__docformat__ = 'restructuredtext'






#! /usr/bin/env python
# -*- coding: utf-8

import os
import sys

from setuptools import setup, find_packages

import crunch

def publish():
    """ publish to pypi """
    os.system("python setup.py sdist upload")

if sys.argv[-1] == "publish":
    publish()
    sys.exit()

required = ['requests', 'client', 'gevent']

setup(
    name = 'crunch',
    version = crunch.__version__,
    description = 'Command line tool download and upload files',
    long_description = open('README.rst').read() + '\n\n' ,
    author = 'kracekumar',
    author_email = 'me@kracekumar.com',
    url = "https://github.com/kracekumar/crunch",
    data_files = [
        'README.rst',
        ],
    packages = find_packages(),
    install_requires = required,
    tests_require = ['nose'],
    entry_points = {
        'console_scripts': ['crunch = crunch.core.main',]
        },
    license = 'ISC',
    classifiers = (
        'Development Status :: 1 - Planning',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: System Administrators',
        'Natural Language :: English',
        'License :: OSI Approved :: ISC License (ISCL)',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.5',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Topic :: Terminals :: Terminal Emulators/X Terminals',
        ),
    )
